//
// pointBrush.cpp
//
// The implementation of Point Brush. It is a kind of ImpBrush. All your brush implementations
// will look like this, although each will probably have different GL primitive calls.
//


#include "impressionistDoc.h"
#include "impressionistUI.h"
#include "pointBrush.h"

extern float frand();

PointBrush::PointBrush( ImpressionistDoc* pDoc, char* name ) :
	ImpBrush(pDoc,name)
{
}

void PointBrush::BrushBegin( const Point source, const Point target )
{

	// Get a pointer to our instance of the document class.  The document
	// class has access to nearly everything that describes the current image.
	ImpressionistDoc* pDoc = GetDocument();
	ImpressionistUI* dlg=pDoc->m_pUI;

	// Since the document contains a pointer to the UI, we can get the user
	// brush selection size from a pointer to the current document instance.
	int size = pDoc->getSize();


	// Set the size of the brush from the UI.  Until changed, this will
	// be the size of points drawn by openGL.  (Remember, its a state machine!)
	glPointSize( (float)size );

	BrushMove( source, target );
}

void PointBrush::BrushMove( const Point source, const Point target )
{
	ImpressionistDoc* pDoc = GetDocument();
	ImpressionistUI* dlg=pDoc->m_pUI;

	if ( pDoc == NULL ) {
		printf( "PointBrush::BrushMove  document is NULL\n" );
		return;
	}


	// GL draw commands are sandwiched between glBegin and glEnd.  See the red
	// openGL book or the class web for more details on this.
	glBegin( GL_POINTS );
		SetColor( source );

		// create a point on the screen of color 'source'.  There are many other 
		// primitives you can draw with openGL.  See the the web or one of the books
		// floating around for the list of functions available.
		glVertex2d( target.x, target.y );

	glEnd();
}

void PointBrush::BrushEnd( const Point source, const Point target )
{
	// do nothing so far . .
	// but will this be the same for all brushes. . .? :)
}

